Button

Struct Button 

pub struct Button<Label, Action> { /* private fields */ }
A button component that can be configured with a label and an action.

Implementations

Source

impl<Label> Button<Label, ()>

pub const fn new(label: Label) -> Self

Creates a new button with the specified label.

Arguments
  • label - The text or view to display on the button
Source

impl<Label, Action> Button<Label, Action>

pub const fn style(self, style: ButtonStyle) -> Self

Sets the visual style of the button.

Arguments
  • style - The button style to apply
Returns

The modified button with the style set

pub fn action<H, P>(self, action: H) -> Button<Label, IntoHandler<H, P, ()>>
where H: HandlerFn<P, ()>, P: 'static,

Sets the action to be performed when the button is clicked.

Arguments
  • action - The callback function to execute when button is clicked
Returns

The modified button with the action set

pub fn action_with<H, P, S>( self, state: &S, action: H, ) -> Button<Label, IntoHandlerWithState<H, P, (), S>>
where H: HandlerFnWithState<P, (), S>, S: 'static + Clone, P: 'static,

Sets the action to be performed when the button is clicked, with access to a state.

Arguments
  • state - A reference to the state that the action can access.
  • action - The callback function to execute when the button is clicked.
Returns

The modified button with the action and state set.