#[non_exhaustive]pub struct ButtonConfig {
pub label: AnyView,
pub action: BoxHandler<()>,
pub style: ButtonStyle,
}Expand description
Configuration for a button component.
Use the Button struct’s methods to customize these properties.
Layout Behavior
Buttons size themselves to fit their label content and never stretch to fill extra space. In a stack, they take only the space they need.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.label: AnyViewThe label displayed on the button
action: BoxHandler<()>The action to execute when the button is clicked
style: ButtonStyleThe visual style of the button